/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */
import type { BucketIn } from '../models/BucketIn';
import type { BucketOut } from '../models/BucketOut';
import type { S3ObjectMetaInformation } from '../models/S3ObjectMetaInformation';

import type { CancelablePromise } from '../core/CancelablePromise';
import { OpenAPI } from '../core/OpenAPI';
import { request as __request } from '../core/request';

export class BucketService {

    /**
     * List buckets of user
     * List the buckets of the current user where the user has READ permissions for.
     *
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketListBuckets(): CancelablePromise<Array<BucketOut>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
            },
        });
    }

    /**
     * Create a bucket for the current user
     * Create a bucket for the current user.
     *
     * The name of the bucket has some constraints.
     * For more information see the [Ceph documentation](https://docs.ceph.com/en/quincy/radosgw/s3/bucketops/#constraints)
     *
     * @param requestBody
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketCreateBucket(
        requestBody: BucketIn,
    ): CancelablePromise<BucketOut> {
        return __request(OpenAPI, {
            method: 'POST',
            url: '/buckets/',
            body: requestBody,
            mediaType: 'application/json',
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get a bucket by its name
     * Get a bucket by its name if the current user has READ permissions for the bucket.
     *
     * @param bucketName Name of bucket
     * @returns BucketOut Successful Response
     * @throws ApiError
     */
    public static bucketGetBucket(
        bucketName: string,
    ): CancelablePromise<BucketOut> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}',
            path: {
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Delete a bucket
     * Delete a bucket by its name. Only the owner of the bucket can delete the bucket.
     *
     * @param bucketName Name of bucket
     * @param forceDelete Delete even non-empty bucket
     * @returns void
     * @throws ApiError
     */
    public static bucketDeleteBucket(
        bucketName: string,
        forceDelete: boolean = false,
    ): CancelablePromise<void> {
        return __request(OpenAPI, {
            method: 'DELETE',
            url: '/buckets/{bucket_name}',
            path: {
                'bucket_name': bucketName,
            },
            query: {
                'force_delete': forceDelete,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get the metadata of the objects in the bucket
     * Get the metadata of the objects in the bucket.
     *
     * @param bucketName Name of bucket
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObjects(
        bucketName: string,
    ): CancelablePromise<Array<S3ObjectMetaInformation>> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects',
            path: {
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

    /**
     * Get the metadata about a specific object
     * Get the metadata of a specific object in a bucket.
     *
     * @param objectPath
     * @param bucketName Name of bucket
     * @returns S3ObjectMetaInformation Successful Response
     * @throws ApiError
     */
    public static objectGetBucketObject(
        objectPath: string,
        bucketName: string,
    ): CancelablePromise<S3ObjectMetaInformation> {
        return __request(OpenAPI, {
            method: 'GET',
            url: '/buckets/{bucket_name}/objects/{object_path}',
            path: {
                'object_path': objectPath,
                'bucket_name': bucketName,
            },
            errors: {
                400: `Error decoding JWT Token`,
                403: `Not authenticated`,
                404: `Entity not Found`,
                422: `Validation Error`,
            },
        });
    }

}
